linchpin drop
=============

.. deprecated:: 1.0.0

This command is an alias for :doc:`linchpincli_linchpin_destroy`, and has been
included for backward compatibility with previous versions of linchpin. It will
be removed in a future version of linchpin.

Users of linchpin should switch to using ``linchpin destroy`` as soon as possible.
